@@ -305,7 +305,7 @@ def find(stmt, session):
     start_offset = session.config["stixquery"]["timerange_start_offset"]
     end_offset = session.config["stixquery"]["timerange_stop_offset"]
 
-    if return_type not in session.store.tables():
+    if return_type not in session.store.types():
         # return empty variable
         output = new_var(session.store, None, [], stmt, session.symtable)
 
@@ -321,7 +321,7 @@ def find(stmt, session):
             )
 
             if (
-                event_type in session.store.tables()
+                event_type in session.store.types()
                 and are_entities_associated_with_x_ibm_event([input_type, return_type])
                 and input_type != return_type
             ):
@@ -456,7 +456,7 @@ def find(stmt, session):
 
         else:
             return_var_table = None
-            _logger.warning(f'no relation "{relation}" on this dataset')
+            _logger.info(f'no relation "{relation}" on this dataset')
 
         output = new_var(session.store, return_var_table, [], stmt, session.symtable)
 
@@ -589,7 +589,7 @@ def _prefetch(
             _logger.debug(f"prefetch successful.")
             return return_var_name
 
-    _logger.warning(f"prefetch return empty.")
+    _logger.info(f"prefetch return empty.")
     return None
 
 
@@ -612,5 +612,5 @@ def _filter_prefetched_process(
         _logger.debug(f"filter successful.")
         return prefetch_filtered_var_name
     else:
-        _logger.warning("no prefetched process found after filtering.")
+        _logger.info("no prefetched process found after filtering.")
         return None
